@@ -32,9 +32,9 @@ sub get_entry_unbuffered {
     return
       if defined( $self->tell_end ) && ( $self->fh->tell > $self->tell_end );
     if ( $self->multiline ) {
-	while ( !$self->fh->eof && !$self->next_line_has_date ) {
-		$line .= $self->getline();
-	}
+        while ( !$self->fh->eof && !$self->next_line_has_date ) {
+            $line .= $self->getline();
+        }
     }
     return $line;
 }
@@ -45,20 +45,26 @@ sub byte_offsets {
     open( my $fh, '<', $filename ) or die "Can't open $filename: $!\n";
     my $test_line = $fh->getline;
     if ( defined($test_line) ) {
-        my ( $epoch, $error ) = $self->to_epoch( $test_line );
+        my ( $epoch, $error ) = $self->to_epoch($test_line);
         if ($error) {
             die "No date found in first line: $error\n";
         }
-        $fh->seek(0, SEEK_SET );
+        $fh->seek( 0, SEEK_SET );
 
-        my $tell_beg = $self->search( $fh, $self->start, format => $self->format, );
+        my $tell_beg =
+          $self->search( $fh, $self->start, format => $self->format, );
 
         if ( defined $tell_beg ) {
-            my $tell_end = $self->search( $fh, $self->end, min_byte => $tell_beg, format => $self->format );
+            my $tell_end = $self->search(
+                $fh, $self->end,
+                min_byte => $tell_beg,
+                format   => $self->format
+            );
 
             return $fh, $tell_beg, $tell_end;
         }
     }
+
     # return for empty file
     return $fh, 0, -1;
 }
@@ -82,42 +88,40 @@ sub search {
 
   BLOCK: while ( $max - $min > 1 ) {
         $mid = int( ( $max + $min ) / 2 );
-        $fh->seek($mid * $blksize, 0 ) or return;
+        $fh->seek( $mid * $blksize, SEEK_SET ) or return;
         $fh->getline if $mid;    # probably a partial line
       LINE: while ( my $line = $fh->getline() ) {
-            my ($epoch) = $self->to_epoch( $line );
+            my ($epoch) = $self->to_epoch($line);
             if ( !$epoch ) {
                 next LINE if $multiline || $self->skip_unparsable;
 
                 chomp($line);
                 die "Unparsable line: $line\n";
             }
-            if ($multiline) {
-                my $byte = $fh->tell;
-                $mid = int( $byte / $blksize );
-            }
+
             $epoch < $key
-              ? $min = $mid
+              ? $min = int( ( $fh->tell - length($line) ) / $blksize )
               : $max = $mid;
+
             next BLOCK;
         }
     }
 
     # find the right line
     $min *= $blksize;
-    $fh->seek( $min, 0 ) or return;
+    $fh->seek( $min, SEEK_SET ) or return;
     $fh->getline if $min;    # probably a partial line
     for ( ; ; ) {
         $min = $fh->tell;
         defined( my $line = $fh->getline ) or last;
-        my ($epoch) = $self->to_epoch( $line );
+        my ($epoch) = $self->to_epoch($line);
         if ( !$epoch ) {
             next if $multiline || $self->skip_unparsable;
             chomp($line);
             die "Unparsable line: $line\n";
         }
         if ( $epoch >= $key ) {
-            $fh->seek($min, 0 );
+            $fh->seek( $min, SEEK_SET );
             return $min;
         }
     }
